@@ -1,9 +1,10 @@
 package Lemonldap::NG::Manager::Cli::Lib;
 
+use strict;
 use Mouse;
 use Lemonldap::NG::Manager;
 
-our $VERSION = '1.9.991_01';
+our $VERSION = '2.0.0';
 
 extends 'Lemonldap::NG::Common::PSGI::Cli::Lib';
 
